# -*- coding: utf-8 -*-
"""Histogram Entities.

@author Hao Song (songhao@vmware.com)
"""
